package PPI::Tiny;

use strict;
use warnings;

=head1 NAME

PPI::Tiny - a minimal Perl Parser

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

    use PPI::Tiny;

    my $foo = PPI::Tiny->new( $document );

    die "Not a Perl document\n" unless $foo;

=head1 EXPORT

None.

=cut

sub new
{
    my ($class, $doc) = @_;
    return unless $doc =~ /^#!.*perl/m;
    bless \$doc, $class;
}

=head1 METHODS

=over 4

=item * C<new( $document )>

Returns a C<PPI::Tiny> object if the contents of C<$document> appear to be a
valid Perl document.  Note that in the interests of avoiding false positives,
this is a little stricter than it could be; it may not recognize I<all> valid
Perl programs and modules.  However, it's much smaller and uses less memory
than L<PPI> so it's more appropriate in more situations.

=back

=head1 AUTHOR

chromatic, C<< <chromatic at wgz.org> >>

=head1 BUGS

Please report any bugs or feature requests to
C<bug-ppi-tiny at rt.cpan.org>, or through the web interface at
L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=PPI-Tiny>.
I will be notified and can happily close all reports that this doesn't actually parse Perl documents.  It's a C<::Tiny> module.  It doesn't have to work.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc PPI::Tiny

You can also look for information at:

=over 4

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/PPI-Tiny>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/PPI-Tiny>

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=PPI-Tiny>

=item * Search CPAN

L<http://search.cpan.org/dist/PPI-Tiny>

=back

=head1 ACKNOWLEDGEMENTS

=head1 COPYRIGHT & LICENSE

Copyright 2007 choromatic, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1; # End of PPI::Tiny
